aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2019-08-06 08:52:02 +0300
committerRoy Ben-Shabat <Roy@Twine-s.com>2019-08-06 08:52:02 +0300
commitc1b00ec58a47e504e0247c21c96b55a89e7a95eb (patch)
tree8f3fd5bf8a5033123336a8ead78c3c7cda9e238f
parent002ca95dd63e65bf9c501198d8bb30c042a14a64 (diff)
downloadTango-c1b00ec58a47e504e0247c21c96b55a89e7a95eb.tar.gz
Tango-c1b00ec58a47e504e0247c21c96b55a89e7a95eb.zip
Added job/brush stops catalogs and colors to Job import/export.
-rw-r--r--Software/PMR/Messages/Exports/JobFile.proto1
-rw-r--r--Software/PMR/Messages/Exports/JobFileBrushStop.proto1
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/BrushStopDTOBase.cs4
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/BrushStopBase.cs18
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/Job.cs24
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/BRUSH_STOPS.cs2
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx10
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram146
-rw-r--r--Software/Visual_Studio/Tango.PMR/Exports/JobFile.cs36
-rw-r--r--Software/Visual_Studio/Tango.PMR/Exports/JobFileBrushStop.cs37
10 files changed, 177 insertions, 102 deletions
diff --git a/Software/PMR/Messages/Exports/JobFile.proto b/Software/PMR/Messages/Exports/JobFile.proto
index 749edb4b1..3516076cd 100644
--- a/Software/PMR/Messages/Exports/JobFile.proto
+++ b/Software/PMR/Messages/Exports/JobFile.proto
@@ -28,4 +28,5 @@ message JobFile
int32 SampleUnitsOrMeters = 19;
double LengthPercentageFactor = 20;
repeated JobFileSegment Segments = 21;
+ string ColorCatalogGuid = 22;
} \ No newline at end of file
diff --git a/Software/PMR/Messages/Exports/JobFileBrushStop.proto b/Software/PMR/Messages/Exports/JobFileBrushStop.proto
index 93444e338..98b7e56ff 100644
--- a/Software/PMR/Messages/Exports/JobFileBrushStop.proto
+++ b/Software/PMR/Messages/Exports/JobFileBrushStop.proto
@@ -32,4 +32,5 @@ message JobFileBrushStop
bool Corrected = 21;
string ColorCatalogGuid = 22;
+ string ColorCatalogItemGuid = 23;
} \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.BL/Entities/Job.cs b/Software/Visual_Studio/Tango.BL/Entities/Job.cs
index 29f9bf439..54ec4bd27 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/Job.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/Job.cs
@@ -595,6 +595,7 @@ namespace Tango.BL.Entities
jobFile.SpoolTypeGuid = job.SpoolTypeGuid;
jobFile.Type = job.Type;
jobFile.WindingMethodGuid = job.WindingMethodGuid;
+ jobFile.ColorCatalogGuid = job.ColorCatalogGuid.ToStringOrEmpty();
foreach (var segment in job.OrderedSegments)
{
@@ -626,10 +627,19 @@ namespace Tango.BL.Entities
job.MachineGuid = machineGuid;
job.UserGuid = userGuid;
- var job_color_space = db.ColorSpaces.SingleOrDefault(x => x.Guid == jobFile.ColorSpaceGuid);
- if (job_color_space == null) throw new ArgumentException("Could not load the specified job file. Job color space could not be located on database.");
- job.ColorSpaceGuid = jobFile.ColorSpaceGuid;
+ if (!String.IsNullOrEmpty(jobFile.ColorSpaceGuid))
+ {
+ var job_color_space = db.ColorSpaces.SingleOrDefault(x => x.Guid == jobFile.ColorSpaceGuid);
+ if (job_color_space == null) throw new ArgumentException("Could not load the specified job file. Job color space could not be located on database.");
+ job.ColorSpaceGuid = jobFile.ColorSpaceGuid;
+ }
+ if (!String.IsNullOrEmpty(jobFile.ColorCatalogGuid))
+ {
+ var job_color_catalog = db.ColorCatalogs.SingleOrDefault(x => x.Guid == jobFile.ColorCatalogGuid);
+ if (job_color_catalog == null) throw new ArgumentException("Could not load the specified job file. Job color catalog could not be located on database.");
+ job.ColorCatalogGuid = jobFile.ColorCatalogGuid;
+ }
var job_customer = db.Customers.FirstOrDefault(x => x.Name == jobFile.Customer);
@@ -695,7 +705,13 @@ namespace Tango.BL.Entities
if (!String.IsNullOrWhiteSpace(stop.ColorCatalogGuid))
{
var stop_color_catalog = db.ColorCatalogs.SingleOrDefault(x => x.Guid == stop.ColorCatalogGuid);
- if (stop_color_catalog == null) throw new ArgumentException("Could not load the specified job file. Job brush stop catalog color could not be located on database.");
+ if (stop_color_catalog == null) throw new ArgumentException("Could not load the specified job file. Job brush stop color catalog could not be located on database.");
+ }
+
+ if (!String.IsNullOrWhiteSpace(stop.ColorCatalogItemGuid))
+ {
+ var stop_color_catalog_item = db.ColorCatalogsItems.SingleOrDefault(x => x.Guid == stop.ColorCatalogItemGuid);
+ if (stop_color_catalog_item == null) throw new ArgumentException("Could not load the specified job file. Job brush stop catalog color could not be located on database.");
}
BrushStop st = new BrushStop();
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/BRUSH_STOPS.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/BRUSH_STOPS.cs
index 60d4a2e98..9d45214fb 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/BRUSH_STOPS.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/BRUSH_STOPS.cs
@@ -49,7 +49,7 @@ namespace Tango.DAL.Remote.DB
public int V7_DIV { get; set; }
public bool CORRECTED { get; set; }
public string COLOR_CATALOG_GUID { get; set; }
- public string COLOR_CATALOGS_ITEM_GUID { get; set; }
+ public string COLOR_CATALOG_ITEM_GUID { get; set; }
public virtual COLOR_CATALOGS COLOR_CATALOGS { get; set; }
public virtual COLOR_CATALOGS_ITEMS COLOR_CATALOGS_ITEMS { get; set; }
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
index 9fdf8bf36..bd09ed8e6 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
@@ -89,7 +89,7 @@
<Property Name="V7_DIV" Type="int" Nullable="false" />
<Property Name="CORRECTED" Type="bit" Nullable="false" />
<Property Name="COLOR_CATALOG_GUID" Type="varchar" MaxLength="36" />
- <Property Name="COLOR_CATALOGS_ITEM_GUID" Type="varchar" MaxLength="36" />
+ <Property Name="COLOR_CATALOG_ITEM_GUID" Type="varchar" MaxLength="36" />
</EntityType>
<EntityType Name="CARTRIDGE_TYPES">
<Key>
@@ -1113,7 +1113,7 @@
<PropertyRef Name="GUID" />
</Principal>
<Dependent Role="BRUSH_STOPS">
- <PropertyRef Name="COLOR_CATALOGS_ITEM_GUID" />
+ <PropertyRef Name="COLOR_CATALOG_ITEM_GUID" />
</Dependent>
</ReferentialConstraint>
</Association>
@@ -3060,7 +3060,7 @@
<Property Name="V7_DIV" Type="Int32" Nullable="false" />
<Property Name="CORRECTED" Type="Boolean" Nullable="false" />
<Property Name="COLOR_CATALOG_GUID" Type="String" MaxLength="36" FixedLength="false" Unicode="false" />
- <Property Name="COLOR_CATALOGS_ITEM_GUID" Type="String" MaxLength="36" FixedLength="false" Unicode="false" />
+ <Property Name="COLOR_CATALOG_ITEM_GUID" Type="String" MaxLength="36" FixedLength="false" Unicode="false" />
<NavigationProperty Name="COLOR_CATALOGS" Relationship="RemoteModel.FK_BRUSH_STOPS_COLOR_CATALOGS" FromRole="BRUSH_STOPS" ToRole="COLOR_CATALOGS" />
<NavigationProperty Name="COLOR_CATALOGS_ITEMS" Relationship="RemoteModel.FK_BRUSH_STOPS_COLOR_CATALOGS_ITEMS" FromRole="BRUSH_STOPS" ToRole="COLOR_CATALOGS_ITEMS" />
<NavigationProperty Name="COLOR_SPACES" Relationship="RemoteModel.FK_BRUSH_STOPS_COLOR_SPACES" FromRole="BRUSH_STOPS" ToRole="COLOR_SPACES" />
@@ -4297,7 +4297,7 @@
<PropertyRef Name="GUID" />
</Principal>
<Dependent Role="BRUSH_STOPS">
- <PropertyRef Name="COLOR_CATALOGS_ITEM_GUID" />
+ <PropertyRef Name="COLOR_CATALOG_ITEM_GUID" />
</Dependent>
</ReferentialConstraint>
</Association>
@@ -5340,7 +5340,7 @@
<EntitySetMapping Name="BRUSH_STOPS">
<EntityTypeMapping TypeName="RemoteModel.BRUSH_STOPS">
<MappingFragment StoreEntitySet="BRUSH_STOPS">
- <ScalarProperty Name="COLOR_CATALOGS_ITEM_GUID" ColumnName="COLOR_CATALOGS_ITEM_GUID" />
+ <ScalarProperty Name="COLOR_CATALOG_ITEM_GUID" ColumnName="COLOR_CATALOG_ITEM_GUID" />
<ScalarProperty Name="COLOR_CATALOG_GUID" ColumnName="COLOR_CATALOG_GUID" />
<ScalarProperty Name="CORRECTED" ColumnName="CORRECTED" />
<ScalarProperty Name="V7_DIV" ColumnName="V7_DIV" />
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
index 3764f370d..d03fb67c4 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
@@ -5,79 +5,79 @@
<!-- Diagram content (shape and connector positions) -->
<edmx:Diagrams>
<Diagram DiagramId="f9ae01d708754bbd997add25a4bacc79" Name="Diagram1">
- <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="3.75" PointY="2.125" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="3.75" PointY="30.625" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="37.875" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="3.75" PointY="43.75" />
- <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="16" PointY="16.5" />
- <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="16.25" PointY="13.5" />
- <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="13.5" PointY="23.25" />
- <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="0.75" PointY="30" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS" Width="1.5" PointX="1.5" PointY="6.125" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_GROUPS" Width="1.5" PointX="0.75" PointY="11.5" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS" Width="1.5" PointX="3" PointY="10.25" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS_RECIPES" Width="1.5" PointX="5.25" PointY="19.125" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="6" PointY="14.625" />
- <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="6" PointY="36.375" />
- <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="3.75" PointY="6.25" />
- <EntityTypeShape EntityType="RemoteModel.CUSTOMER" Width="1.5" PointX="8.25" PointY="17.375" />
- <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="14" PointY="5.25" />
- <EntityTypeShape EntityType="RemoteModel.DISPENSER" Width="1.5" PointX="16.25" PointY="4.75" />
- <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="40.75" />
- <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="13.25" PointY="32.75" />
- <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="33.25" />
- <EntityTypeShape EntityType="RemoteModel.FIBER_SYNTHS" Width="1.5" PointX="0.75" PointY="36.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWER_TYPES" Width="1.5" PointX="3.75" PointY="47.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWERS" Width="1.5" PointX="6" PointY="31.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSOR_TYPES" Width="1.5" PointX="3.75" PointY="51.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSORS" Width="1.5" PointX="6" PointY="41.875" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCER_TYPES" Width="1.5" PointX="13.75" PointY="46.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCERS" Width="1.5" PointX="16" PointY="32.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTOR_TYPES" Width="1.5" PointX="8.75" PointY="43.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTORS" Width="1.5" PointX="11" PointY="37.875" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROL_TYPES" Width="1.5" PointX="11.75" PointY="50.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROLS" Width="1.5" PointX="14" PointY="38.25" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSOR_TYPES" Width="1.5" PointX="8.75" PointY="39.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSORS" Width="1.5" PointX="11" PointY="33.875" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="33.625" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDER_TYPES" Width="1.5" PointX="14.75" PointY="50.125" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDERS" Width="1.5" PointX="17" PointY="38" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="16.25" PointY="9.375" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="18.5" PointY="20.75" />
- <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="12.75" PointY="28" />
- <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="10.5" PointY="19.875" />
- <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="19.125" />
- <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="11.25" PointY="5.625" />
- <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES_RMLS" Width="1.5" PointX="5.25" PointY="23.375" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE_STUDIO_VERSIONS" Width="1.5" PointX="10.5" PointY="53.5" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="6" PointY="27.375" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="8.25" PointY="20.625" />
- <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="15.5" PointY="27.125" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="23.625" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="16.125" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="27" />
- <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="16.25" PointY="42" />
- <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="6" PointY="0.75" />
- <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="14.25" PointY="53.75" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="52.875" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="54.5" />
- <EntityTypeShape EntityType="RemoteModel.RML" Width="1.5" PointX="3" PointY="20.25" />
- <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="8.25" PointY="46.625" />
- <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="16.5" PointY="46.75" />
- <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="12.75" PointY="19.5" />
- <EntityTypeShape EntityType="RemoteModel.SPOOL_TYPES" Width="1.5" PointX="6" PointY="7.625" />
- <EntityTypeShape EntityType="RemoteModel.SPOOL" Width="1.5" PointX="10.5" PointY="15.25" />
- <EntityTypeShape EntityType="RemoteModel.sysdiagram" Width="1.5" PointX="0.75" PointY="2.875" />
- <EntityTypeShape EntityType="RemoteModel.TANGO_VERSIONS" Width="1.5" PointX="18.5" PointY="31.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_CONTROLLERS" Width="1.5" PointX="8.75" PointY="9.875" />
- <EntityTypeShape EntityType="RemoteModel.TECH_DISPENSERS" Width="1.5" PointX="10.75" PointY="9.875" />
- <EntityTypeShape EntityType="RemoteModel.TECH_HEATERS" Width="1.5" PointX="12.75" PointY="9.875" />
- <EntityTypeShape EntityType="RemoteModel.TECH_IOS" Width="1.5" PointX="12.75" PointY="12.875" />
- <EntityTypeShape EntityType="RemoteModel.TECH_MONITORS" Width="1.5" PointX="18.75" PointY="2.875" />
- <EntityTypeShape EntityType="RemoteModel.TECH_VALVES" Width="1.5" PointX="18.75" PointY="7.875" />
- <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="8.25" PointY="33.625" />
- <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="10.5" PointY="30.75" />
- <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="8.25" PointY="30.5" />
+ <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="3.75" PointY="39" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="3.75" PointY="62.125" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="59.25" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="3.75" PointY="52" />
+ <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="15.75" PointY="21.875" />
+ <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="9" PointY="67.125" />
+ <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="5.25" PointY="18.75" />
+ <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="0.75" PointY="32.5" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS" Width="1.5" PointX="1.5" PointY="5.75" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_GROUPS" Width="1.5" PointX="0.75" PointY="11.125" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS" Width="1.5" PointX="3" PointY="9.875" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS_RECIPES" Width="1.5" PointX="5.25" PointY="22.75" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="6" PointY="15" />
+ <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="6" PointY="54.75" />
+ <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="3.75" PointY="43.125" />
+ <EntityTypeShape EntityType="RemoteModel.CUSTOMER" Width="1.5" PointX="9" PointY="39.75" />
+ <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="6.75" PointY="71.625" />
+ <EntityTypeShape EntityType="RemoteModel.DISPENSER" Width="1.5" PointX="9" PointY="71.125" />
+ <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="49.125" />
+ <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="8.25" PointY="1.875" />
+ <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="26.625" />
+ <EntityTypeShape EntityType="RemoteModel.FIBER_SYNTHS" Width="1.5" PointX="0.75" PointY="35.75" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWER_TYPES" Width="1.5" PointX="6.75" PointY="67.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWERS" Width="1.5" PointX="9" PointY="51.125" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSOR_TYPES" Width="1.5" PointX="9.75" PointY="75.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSORS" Width="1.5" PointX="12" PointY="55.25" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCER_TYPES" Width="1.5" PointX="3.75" PointY="35.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCERS" Width="1.5" PointX="6" PointY="49.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTOR_TYPES" Width="1.5" PointX="9.75" PointY="47.375" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTORS" Width="1.5" PointX="12" PointY="45.25" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROL_TYPES" Width="1.5" PointX="3.75" PointY="65.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROLS" Width="1.5" PointX="6" PointY="59.625" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSOR_TYPES" Width="1.5" PointX="6.75" PointY="79.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSORS" Width="1.5" PointX="9" PointY="59.25" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="3.75" PointY="54.875" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDER_TYPES" Width="1.5" PointX="6.75" PointY="75.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDERS" Width="1.5" PointX="9" PointY="55.375" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="9" PointY="63.875" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="11.25" PointY="35" />
+ <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="13.5" PointY="21.125" />
+ <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="11.25" PointY="19.375" />
+ <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="23.25" />
+ <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="3" PointY="15.75" />
+ <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES_RMLS" Width="1.5" PointX="8.25" PointY="23" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE_STUDIO_VERSIONS" Width="1.5" PointX="10.5" PointY="8.5" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="6" PointY="35.75" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="8.25" PointY="13.25" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="10.5" PointY="14.75" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="15.75" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="18.75" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="29.5" />
+ <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="9" PointY="43.75" />
+ <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="6" PointY="41.125" />
+ <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="11.25" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="28.875" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="30.5" />
+ <EntityTypeShape EntityType="RemoteModel.RML" Width="1.5" PointX="3" PointY="19.875" />
+ <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="11.25" PointY="4.625" />
+ <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="13.5" PointY="4.75" />
+ <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="13.5" PointY="24.875" />
+ <EntityTypeShape EntityType="RemoteModel.SPOOL_TYPES" Width="1.5" PointX="6" PointY="45" />
+ <EntityTypeShape EntityType="RemoteModel.SPOOL" Width="1.5" PointX="13.5" PointY="15.75" />
+ <EntityTypeShape EntityType="RemoteModel.sysdiagram" Width="1.5" PointX="0.75" PointY="2.5" />
+ <EntityTypeShape EntityType="RemoteModel.TANGO_VERSIONS" Width="1.5" PointX="16.5" PointY="17.375" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_CONTROLLERS" Width="1.5" PointX="3.75" PointY="2.5" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_DISPENSERS" Width="1.5" PointX="3.75" PointY="6.5" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_HEATERS" Width="1.5" PointX="12.75" PointY="12.5" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_IOS" Width="1.5" PointX="15.75" PointY="2.5" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_MONITORS" Width="1.5" PointX="15.75" PointY="7.5" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_VALVES" Width="1.5" PointX="15.75" PointY="12.5" />
+ <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="8.25" PointY="7.75" />
+ <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="13.5" PointY="8.75" />
+ <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="9" PointY="36.625" />
<AssociationConnector Association="RemoteModel.FK_ORGANIZATIONS_ADDRESSES" />
<AssociationConnector Association="RemoteModel.FK_USERS_ADDRESSES" />
<AssociationConnector Association="RemoteModel.FK_CONFIGURATIONS_APPLICATION_DISPLAY_PANEL_VERSIONS" />
diff --git a/Software/Visual_Studio/Tango.PMR/Exports/JobFile.cs b/Software/Visual_Studio/Tango.PMR/Exports/JobFile.cs
index 00d398e30..7aa03c4cb 100644
--- a/Software/Visual_Studio/Tango.PMR/Exports/JobFile.cs
+++ b/Software/Visual_Studio/Tango.PMR/Exports/JobFile.cs
@@ -23,7 +23,7 @@ namespace Tango.PMR.Exports {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"Cg1Kb2JGaWxlLnByb3RvEhFUYW5nby5QTVIuRXhwb3J0cxoUSm9iRmlsZVNl",
- "Z21lbnQucHJvdG8ioQQKB0pvYkZpbGUSDAoETmFtZRgBIAEoCRITCgtEZXNj",
+ "Z21lbnQucHJvdG8iuwQKB0pvYkZpbGUSDAoETmFtZRgBIAEoCRITCgtEZXNj",
"cmlwdGlvbhgCIAEoCRIaChJFbmFibGVJbnRlclNlZ21lbnQYAyABKAgSGgoS",
"SW50ZXJTZWdtZW50TGVuZ3RoGAQgASgBEg8KB1JtbEd1aWQYBSABKAkSGQoR",
"V2luZGluZ01ldGhvZEd1aWQYBiABKAkSFQoNU3Bvb2xUeXBlR3VpZBgHIAEo",
@@ -35,12 +35,12 @@ namespace Tango.PMR.Exports {
"aXN0cmlidXRpb24YESABKAUSFQoNTnVtYmVyT2ZIZWFkcxgSIAEoBRIbChNT",
"YW1wbGVVbml0c09yTWV0ZXJzGBMgASgFEh4KFkxlbmd0aFBlcmNlbnRhZ2VG",
"YWN0b3IYFCABKAESMwoIU2VnbWVudHMYFSADKAsyIS5UYW5nby5QTVIuRXhw",
- "b3J0cy5Kb2JGaWxlU2VnbWVudEIdChtjb20udHdpbmUudGFuZ28ucG1yLmV4",
- "cG9ydHNiBnByb3RvMw=="));
+ "b3J0cy5Kb2JGaWxlU2VnbWVudBIYChBDb2xvckNhdGFsb2dHdWlkGBYgASgJ",
+ "Qh0KG2NvbS50d2luZS50YW5nby5wbXIuZXhwb3J0c2IGcHJvdG8z"));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { global::Tango.PMR.Exports.JobFileSegmentReflection.Descriptor, },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Exports.JobFile), global::Tango.PMR.Exports.JobFile.Parser, new[]{ "Name", "Description", "EnableInterSegment", "InterSegmentLength", "RmlGuid", "WindingMethodGuid", "SpoolTypeGuid", "EnableLubrication", "HasEmbroideryFile", "EmbroideryFileData", "EmbroideryFileName", "EmbroideryJpeg", "ColorSpaceGuid", "NumberOfUnits", "Type", "Customer", "SpoolsDistribution", "NumberOfHeads", "SampleUnitsOrMeters", "LengthPercentageFactor", "Segments" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Exports.JobFile), global::Tango.PMR.Exports.JobFile.Parser, new[]{ "Name", "Description", "EnableInterSegment", "InterSegmentLength", "RmlGuid", "WindingMethodGuid", "SpoolTypeGuid", "EnableLubrication", "HasEmbroideryFile", "EmbroideryFileData", "EmbroideryFileName", "EmbroideryJpeg", "ColorSpaceGuid", "NumberOfUnits", "Type", "Customer", "SpoolsDistribution", "NumberOfHeads", "SampleUnitsOrMeters", "LengthPercentageFactor", "Segments", "ColorCatalogGuid" }, null, null, null)
}));
}
#endregion
@@ -92,6 +92,7 @@ namespace Tango.PMR.Exports {
sampleUnitsOrMeters_ = other.sampleUnitsOrMeters_;
lengthPercentageFactor_ = other.lengthPercentageFactor_;
segments_ = other.segments_.Clone();
+ colorCatalogGuid_ = other.colorCatalogGuid_;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -329,6 +330,17 @@ namespace Tango.PMR.Exports {
get { return segments_; }
}
+ /// <summary>Field number for the "ColorCatalogGuid" field.</summary>
+ public const int ColorCatalogGuidFieldNumber = 22;
+ private string colorCatalogGuid_ = "";
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public string ColorCatalogGuid {
+ get { return colorCatalogGuid_; }
+ set {
+ colorCatalogGuid_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
+ }
+ }
+
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override bool Equals(object other) {
return Equals(other as JobFile);
@@ -363,6 +375,7 @@ namespace Tango.PMR.Exports {
if (SampleUnitsOrMeters != other.SampleUnitsOrMeters) return false;
if (LengthPercentageFactor != other.LengthPercentageFactor) return false;
if(!segments_.Equals(other.segments_)) return false;
+ if (ColorCatalogGuid != other.ColorCatalogGuid) return false;
return true;
}
@@ -390,6 +403,7 @@ namespace Tango.PMR.Exports {
if (SampleUnitsOrMeters != 0) hash ^= SampleUnitsOrMeters.GetHashCode();
if (LengthPercentageFactor != 0D) hash ^= LengthPercentageFactor.GetHashCode();
hash ^= segments_.GetHashCode();
+ if (ColorCatalogGuid.Length != 0) hash ^= ColorCatalogGuid.GetHashCode();
return hash;
}
@@ -481,6 +495,10 @@ namespace Tango.PMR.Exports {
output.WriteDouble(LengthPercentageFactor);
}
segments_.WriteTo(output, _repeated_segments_codec);
+ if (ColorCatalogGuid.Length != 0) {
+ output.WriteRawTag(178, 1);
+ output.WriteString(ColorCatalogGuid);
+ }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -547,6 +565,9 @@ namespace Tango.PMR.Exports {
size += 2 + 8;
}
size += segments_.CalculateSize(_repeated_segments_codec);
+ if (ColorCatalogGuid.Length != 0) {
+ size += 2 + pb::CodedOutputStream.ComputeStringSize(ColorCatalogGuid);
+ }
return size;
}
@@ -616,6 +637,9 @@ namespace Tango.PMR.Exports {
LengthPercentageFactor = other.LengthPercentageFactor;
}
segments_.Add(other.segments_);
+ if (other.ColorCatalogGuid.Length != 0) {
+ ColorCatalogGuid = other.ColorCatalogGuid;
+ }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -710,6 +734,10 @@ namespace Tango.PMR.Exports {
segments_.AddEntriesFrom(input, _repeated_segments_codec);
break;
}
+ case 178: {
+ ColorCatalogGuid = input.ReadString();
+ break;
+ }
}
}
}
diff --git a/Software/Visual_Studio/Tango.PMR/Exports/JobFileBrushStop.cs b/Software/Visual_Studio/Tango.PMR/Exports/JobFileBrushStop.cs
index 5fa9a2eab..26dec4be0 100644
--- a/Software/Visual_Studio/Tango.PMR/Exports/JobFileBrushStop.cs
+++ b/Software/Visual_Studio/Tango.PMR/Exports/JobFileBrushStop.cs
@@ -22,7 +22,7 @@ namespace Tango.PMR.Exports {
static JobFileBrushStopReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChZKb2JGaWxlQnJ1c2hTdG9wLnByb3RvEhFUYW5nby5QTVIuRXhwb3J0cyLX",
+ "ChZKb2JGaWxlQnJ1c2hTdG9wLnByb3RvEhFUYW5nby5QTVIuRXhwb3J0cyL1",
"AgoQSm9iRmlsZUJydXNoU3RvcBIWCg5Db2xvclNwYWNlR3VpZBgBIAEoCRIV",
"Cg1PZmZzZXRQZXJjZW50GAIgASgBEgwKBEN5YW4YAyABKAESDwoHTWFnZW50",
"YRgEIAEoARIOCgZZZWxsb3cYBSABKAESDQoFQmxhY2sYBiABKAESCwoDUmVk",
@@ -30,12 +30,13 @@ namespace Tango.PMR.Exports {
"ARIJCgFBGAsgASgBEgkKAUIYDCABKAESCgoCVjAYDSABKAESCgoCVjEYDiAB",
"KAESCgoCVjIYDyABKAESCgoCVjMYECABKAESCgoCVjQYESABKAESCgoCVjUY",
"EiABKAESCgoCVjYYEyABKAESCgoCVjcYFCABKAESEQoJQ29ycmVjdGVkGBUg",
- "ASgIEhgKEENvbG9yQ2F0YWxvZ0d1aWQYFiABKAlCHQobY29tLnR3aW5lLnRh",
- "bmdvLnBtci5leHBvcnRzYgZwcm90bzM="));
+ "ASgIEhgKEENvbG9yQ2F0YWxvZ0d1aWQYFiABKAkSHAoUQ29sb3JDYXRhbG9n",
+ "SXRlbUd1aWQYFyABKAlCHQobY29tLnR3aW5lLnRhbmdvLnBtci5leHBvcnRz",
+ "YgZwcm90bzM="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Exports.JobFileBrushStop), global::Tango.PMR.Exports.JobFileBrushStop.Parser, new[]{ "ColorSpaceGuid", "OffsetPercent", "Cyan", "Magenta", "Yellow", "Black", "Red", "Green", "Blue", "L", "A", "B", "V0", "V1", "V2", "V3", "V4", "V5", "V6", "V7", "Corrected", "ColorCatalogGuid" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Exports.JobFileBrushStop), global::Tango.PMR.Exports.JobFileBrushStop.Parser, new[]{ "ColorSpaceGuid", "OffsetPercent", "Cyan", "Magenta", "Yellow", "Black", "Red", "Green", "Blue", "L", "A", "B", "V0", "V1", "V2", "V3", "V4", "V5", "V6", "V7", "Corrected", "ColorCatalogGuid", "ColorCatalogItemGuid" }, null, null, null)
}));
}
#endregion
@@ -88,6 +89,7 @@ namespace Tango.PMR.Exports {
v7_ = other.v7_;
corrected_ = other.corrected_;
colorCatalogGuid_ = other.colorCatalogGuid_;
+ colorCatalogItemGuid_ = other.colorCatalogItemGuid_;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -337,6 +339,17 @@ namespace Tango.PMR.Exports {
}
}
+ /// <summary>Field number for the "ColorCatalogItemGuid" field.</summary>
+ public const int ColorCatalogItemGuidFieldNumber = 23;
+ private string colorCatalogItemGuid_ = "";
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public string ColorCatalogItemGuid {
+ get { return colorCatalogItemGuid_; }
+ set {
+ colorCatalogItemGuid_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
+ }
+ }
+
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override bool Equals(object other) {
return Equals(other as JobFileBrushStop);
@@ -372,6 +385,7 @@ namespace Tango.PMR.Exports {
if (V7 != other.V7) return false;
if (Corrected != other.Corrected) return false;
if (ColorCatalogGuid != other.ColorCatalogGuid) return false;
+ if (ColorCatalogItemGuid != other.ColorCatalogItemGuid) return false;
return true;
}
@@ -400,6 +414,7 @@ namespace Tango.PMR.Exports {
if (V7 != 0D) hash ^= V7.GetHashCode();
if (Corrected != false) hash ^= Corrected.GetHashCode();
if (ColorCatalogGuid.Length != 0) hash ^= ColorCatalogGuid.GetHashCode();
+ if (ColorCatalogItemGuid.Length != 0) hash ^= ColorCatalogItemGuid.GetHashCode();
return hash;
}
@@ -498,6 +513,10 @@ namespace Tango.PMR.Exports {
output.WriteRawTag(178, 1);
output.WriteString(ColorCatalogGuid);
}
+ if (ColorCatalogItemGuid.Length != 0) {
+ output.WriteRawTag(186, 1);
+ output.WriteString(ColorCatalogItemGuid);
+ }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -569,6 +588,9 @@ namespace Tango.PMR.Exports {
if (ColorCatalogGuid.Length != 0) {
size += 2 + pb::CodedOutputStream.ComputeStringSize(ColorCatalogGuid);
}
+ if (ColorCatalogItemGuid.Length != 0) {
+ size += 2 + pb::CodedOutputStream.ComputeStringSize(ColorCatalogItemGuid);
+ }
return size;
}
@@ -643,6 +665,9 @@ namespace Tango.PMR.Exports {
if (other.ColorCatalogGuid.Length != 0) {
ColorCatalogGuid = other.ColorCatalogGuid;
}
+ if (other.ColorCatalogItemGuid.Length != 0) {
+ ColorCatalogItemGuid = other.ColorCatalogItemGuid;
+ }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -741,6 +766,10 @@ namespace Tango.PMR.Exports {
ColorCatalogGuid = input.ReadString();
break;
}
+ case 186: {
+ ColorCatalogItemGuid = input.ReadString();
+ break;
+ }
}
}
}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/BrushStopDTOBase.cs b/Software/Visual_Studio/Tango.BL/DTO/BrushStopDTOBase.cs
index 41fa3ed57..7b73c4f64 100644
--- a/Software/Visual_Studio/Tango.BL/DTO/BrushStopDTOBase.cs
+++ b/Software/Visual_Studio/Tango.BL/DTO/BrushStopDTOBase.cs
@@ -278,9 +278,9 @@ namespace Tango.BL.DTO
}
/// <summary>
/// color catalogs item guid
/// </summary>
- public String ColorCatalogsItemGuid
+ public String ColorCatalogItemGuid
{
get; set;
}
@@ -278,9 +278,9 @@ namespace Tango.BL.DTO
}
/// <summary>
- /// color catalogs item guid
+ /// color catalog item guid
/// </summary>
diff --git a/Software/Visual_Studio/Tango.BL/Entities/BrushStopBase.cs b/Software/Visual_Studio/Tango.BL/Entities/BrushStopBase.cs
index 7397d952d..affa6fba9 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/BrushStopBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/BrushStopBase.cs
@@ -952,27 +952,27 @@ namespace Tango.BL.Entities
}
}
- protected String _colorcatalogsitemguid;
+ protected String _colorcatalogitemguid;
/// <summary>
/// Gets or sets the brushstopbase color catalogs item guid.
/// </summary>
- [Column("COLOR_CATALOGS_ITEM_GUID")]
- [ForeignKey("ColorCatalogsItem")]
+ [Column("COLOR_CATALOG_ITEM_GUID")]
+ [ForeignKey("ColorCatalogItem")]
- public String ColorCatalogsItemGuid
+ public String ColorCatalogItemGuid
{
get
{
- return _colorcatalogsitemguid;
+ return _colorcatalogitemguid;
}
set
{
- if (_colorcatalogsitemguid != value)
+ if (_colorcatalogitemguid != value)
{
- _colorcatalogsitemguid = value;
+ _colorcatalogitemguid = value;
}
}
@@ -1033,7 +1033,7 @@ namespace Tango.BL.Entities
if (ColorCatalogsItem != null)
{
- ColorCatalogsItemGuid = ColorCatalogsItem.Guid;
+ ColorCatalogItemGuid = ColorCatalogsItem.Guid;
}
OnColorCatalogsItemChanged(value);
@@ -952,27 +952,27 @@ namespace Tango.BL.Entities
/// <summary>
- /// Gets or sets the brushstopbase color catalogs item guid.
+ /// Gets or sets the brushstopbase color catalog item guid.
/// </summary>